import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, Tabs, Radio, DatePicker, message, Upload } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import moment from 'moment';
import router from 'umi/router';
import styles from '../../../../style/GoodsList.less';
import XForm, { FieldTypes } from '../../../../../components/XForm';
import apis from '../../../../../services/apis';
import BuildSelect from '../../../../../components/SelectButton/BuildSelect';
import CitySelect from '../../../../../components/SelectButton/CitySelect';
import request from '../../../../../utils/request';

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
const { TextArea } = Input;

let detailVisible = true;
let urlVisible = false;

const setExtraData = (data) => {
  detailVisible = data.newsDetailType == '1'
  urlVisible = data.newsDetailType == '0'
}

const Base = props => {
  const salesBatchId = props.salesBatchId.batchId
  const [ saleBatchData, setSaleBatchData ] = useState({})
  const [showHelp, setShowHelp] = useState(false)
  
  if(salesBatchId){
    useEffect(() => {
      getSaleBatchData(salesBatchId);
    },[])

  // 查询列表
  const getSaleBatchData = (salesBatchId) => {
    request({ ...apis.house.getTaSalesBatch, urlData: {id: salesBatchId} }).then((data) => {
        console.log(data)
        setSaleBatchData(data)
        if(data.qrCode == 'null'){
          message.error("暂时无法获取二维码")
        }
    })
  }
  }

  const cancelPage = () =>{
    router.push({
      pathname: '/house/list',
    });
  }
  const fields = [
    {
      label: '所属城市',
      name: 'cityId',
      render: <CitySelect />,
      value: saleBatchData.cityId,
      rules: [
        {
          required: true,
          message: '请选择销售楼盘',
        },
      ],
    },
    {
      label: '所属楼盘',
      name: 'buildingId',
      render: <BuildSelect />,
      value: saleBatchData.buildingId,
      rules: [
        {
          required: true,
          message: '请选择销售楼盘',
        },
      ],
    },
    {
      label: '直播活动标题',
      name: 'liveActivityTitle',
      type: FieldTypes.Text,
      value: saleBatchData.liveActivityTitle,
      rules: [
        {
          required: true,
          message: '销售批次名不合法',
          max:20,
        },
      ],
    },
    {
      label: '直播小程序',
      name: 'liveApp',
      type: FieldTypes.Select,
      dict: [{label:"腾讯NOW直播(推荐)",value:1},{label:"斗鱼直播",value:2},{label:"虎牙直播",value:3},{label:"映客直播",value:4},{label:"一直播",value:5}],
      value: saleBatchData.status != null ? saleBatchData.status : 1,
      rules: [
        {
          required: true,
          message: '请选择直播小程序',
        },
      ],
    },
    {
      label: '房间参数',
      name: 'liveRoomParam',
      type: FieldTypes.Text,
      value: saleBatchData.liveRoomParam,
      rules: [
        {
          required: true,
          message: '最多1000字',
          max:1000
        }
      ],
    },
    {
      label: '封面图1',
      name: 'listImg',
      type: FieldTypes.ImageUploader,
      value: saleBatchData.listImg,
      help: '建议尺寸：750px*420px，比例16:9，格式：jpg，用于：活动列表',
      rules: [
        {
          required: true,
          message: '请选择封面图1',
        },
      ],
    },
    {
      label: '封面图2',
      name: 'detailImg',
      type: FieldTypes.ImageUploader,
      value: saleBatchData.detailImg,
      help: '建议尺寸：750*250，比例3:1，格式：jpg，用于：项目详情页',
      rules: [
        {
          required: true,
          message: '请选择封面图2',
        },
      ],
    },
    {
      label: '详情类型',
      name: 'status',
      render: <Radio.Group> 
              <Radio value={1}>系统模板</Radio>
              <Radio value={0}>自定义</Radio>
              </Radio.Group>,
      value: saleBatchData.status - 0,
      rules: [
        {required: true, message: '请选择详情类型'},
      ]
    },

    {
      label: '系统模板图',
      name: 'detailImg',
      hidden: () => !detailVisible,
      type: FieldTypes.ImageUploader,
      value: saleBatchData.detailImg,
      help: '建议尺寸：750*250，比例3:1，格式：jpg，用于：项目详情页',
      rules: [
        {
          required: true,
          message: '请选择封面图2',
        },
      ],
    },
    {
      label: '自定义图',
      name: 'detailImg',
      hidden: () => !urlVisible,
      type: FieldTypes.ImageUploader,
      value: saleBatchData.detailImg,
      help: '建议尺寸：750*250，比例3:1，格式：jpg，用于：项目详情页',
      rules: [
        {
          required: true,
          message: '请选择封面图2',
        },
      ],
    },

    {
      label: '发布状态',
      name: 'status',
      type: FieldTypes.Select,
      dict: [{label:"否",value:0},{label:"是",value:1}],
      value: saleBatchData.status != null ? saleBatchData.status : 1,
      rules: [
        {
          required: true,
          message: '请选择发布状态',
        },
      ],
    },
    {
      label: '扫码查看房源列表',
      name: 'qrCode',
      type: FieldTypes.ImageUploader,
      value: saleBatchData.qrCode,
      props: {disabled: true },
    },
  ]
  
  const handleFormValueChange = (props, changedValues, allValues) => {
    console(allValues, 'allValues')
    setExtraData(allValues)
}

    const handleSubmit = values => { 
      let {preSelectTime, ...submitValue} = values
        if(null != preSelectTime && preSelectTime.length > 0){
          const [preselectionStartTime, preselectionEndTime] = preSelectTime
          submitValue.preselectionStartTime = moment(preselectionStartTime).format('YYYY-MM-DD HH:mm:ss');
          submitValue.preselectionEndTime = moment(preselectionEndTime).format('YYYY-MM-DD HH:mm:ss');
        }else{
          submitValue.preselectionStartTime = null
          submitValue.preselectionEndTime = null
        }        
        console.log(submitValue)
        request({ ...apis.house.updateTaSalesBatch, urlData: {id: salesBatchId},data: submitValue, }).then((data) => {
          message.info("保存成功")
          cancelPage()
        }).catch((err) => {
        message.info(err.msg || err.message)
      })
    }
    
  return (
    <>
      <XForm onSubmit={handleSubmit} onCancel={cancelPage} fields={fields} onValuesChange={handleFormValueChange}></XForm>
    </>
  );
}

export default Base
